==> ukui-menu_2.0.4.orig.tar.gz: ukui-menu/src/UtilityFunction/listview.h <==
/*
 * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
 *
 */

#ifndef LISTVIEW_H
#define LISTVIEW_H
#include <QListView>
#include <QStandardItem>
#include <QEvent>
#include <QScrollBar>
#include <QStandardItemModel>
#include "src/Style/style.h"
#include "src/RightClickMenu/rightclickmenu.h"
#include <QSettings>
#include "src/Interface/ukuimenuinterface.h"
#include "itemdelegate.h"

class ListView : public QListView
{
    Q_OBJECT
public:
    ListView(QWidget *parent, int width, int height, int module);
    ~ListView();

    void addData(QVector<QStringList> data);
    void updateData(QVector<QStringList> data);

protected:
    void initWidget();
    void enterEvent(QEvent* e) Q_DECL_OVERRIDE;
    void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;

private:
//    ListModel* model=nullptr;
    QStandardItemModel* listmodel=nullptr;
    int w=0;
    int h=0;
    int module=0;
    UkuiMenuInterface* pUkuiMenuInterface=nullptr;
//    QStringList rowlist;//存放分类字母所在行

    RightClickMenu* menu;//右键菜单
    QSettings *setting=nullptr;
    QVector<QStringList> data;
    ItemDelegate* m_delegate=nullptr;

private Q_SLOTS:
    void onClicked(QModelIndex index);//点击item
    void rightClickedSlot();//右键菜单

Q_SIGNALS:
    void sendItemClickedSignal(QStringList arg);//向字母排序或功能分类模块发送item点击信号
    void sendFixedOrUnfixedSignal();//向字母排序、功能分类发送固定或者取消固定信号
    void sendUpdateAppListSignal();//向CommonUseWidget发送更新应用列表信号
    void sendHideMainWindowSignal();
};

#endif // LISTVIEW_H

==> ukui-menu_2.0.6.orig.tar.gz: ukui-menu/src/UtilityFunction/listview.h <==
/*
 * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
 *
 */

#ifndef LISTVIEW_H
#define LISTVIEW_H
#include <QListView>
#include <QStandardItem>
#include <QEvent>
#include <QScrollBar>
#include <QStandardItemModel>
#include "src/Style/style.h"
#include "src/RightClickMenu/rightclickmenu.h"
#include <QSettings>
#include "src/Interface/ukuimenuinterface.h"
#include "itemdelegate.h"

class ListView : public QListView
{
    Q_OBJECT
public:
    ListView(QWidget *parent, int width, int height, int module);
    ~ListView();

    void addData(QVector<QStringList> data);
    void updateData(QVector<QStringList> data);

protected:
    void initWidget();
    void enterEvent(QEvent* e) Q_DECL_OVERRIDE;
    void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;

private:
    QStandardItemModel* listmodel=nullptr;
    int w=0;
    int h=0;
    int module=0;
    UkuiMenuInterface* pUkuiMenuInterface=nullptr;

    RightClickMenu* menu=nullptr;//右键菜单
    QSettings *setting=nullptr;
    QVector<QStringList> data;
    ItemDelegate* m_delegate=nullptr;

private Q_SLOTS:
    void onClicked(QModelIndex index);//点击item
    void rightClickedSlot();//右键菜单

Q_SIGNALS:
    void sendItemClickedSignal(QStringList arg);//向字母排序或功能分类模块发送item点击信号
    void sendFixedOrUnfixedSignal(QString desktopfp,int type);//向字母排序、功能分类发送固定或者取消固定信号
    void sendUpdateAppListSignal(QString desktopfp,int type);//向CommonUseWidget发送更新应用列表信号
    void removeListItemSignal(QString desktopfp);
    void removeListAllItemSignal();
    void sendHideMainWindowSignal();
};

#endif // LISTVIEW_H
